searchNodes=[{"doc":"Documentation for WebhooksEmitter.","ref":"WebhooksEmitter.html","title":"WebhooksEmitter","type":"module"},{"doc":"Attaches a new emitter to the event. emitter_id must be unique, if another emitter with the same ID already exists {:error, :already_exists} is returned. Each emitter is a separate process that performs HTTP operations, while keeping a queue of events in order to performs retries. So events handled by the same emitter are processed sequentially. This means also that if a request fails and more events are to be handled by the emitter, the events are queued until the current delivery succeed or fails because of hitting the maximum retries. At this point the event is lost forever. If same url needs to process many events, attach_many/3 can be used.","ref":"WebhooksEmitter.html#attach/3","title":"WebhooksEmitter.attach/3","type":"function"},{"doc":"Attaches a new emitter to a list of events. Accepts a list of event names. Apart from that, works like attach/3.","ref":"WebhooksEmitter.html#attach_many/3","title":"WebhooksEmitter.attach_many/3","type":"function"},{"doc":"Detaches an emitter. Stops the process and removes it from the supervision tree, disregarding any queued message. Always returns :ok.","ref":"WebhooksEmitter.html#detach/1","title":"WebhooksEmitter.detach/1","type":"function"},{"doc":"Emits an event, invoking all emitters attached to it. Allows to set a request_id, that is inserted into the HTTP request as X-Webhooks-Delivery private header. If the request id is not set, a new one is generated and returned as {:ok, UUID.uuid4()}. Otherwise just return the {:ok, request_id} tuple. The map payload is parsed in order to be safe for json encoding, basically ensures that any key or value that cannot be directly converted to string is handled correctly by inspecting them. So keys and values in the payload are converted like: values as tuples are transformed to list keys as tuples are transformed to list, then inspected to obtain a string keys as list are inspected to obtain a string refs are always inspected","ref":"WebhooksEmitter.html#emit/3","title":"WebhooksEmitter.emit/3","type":"function"},{"doc":"","ref":"WebhooksEmitter.html#t:emitter_id/0","title":"WebhooksEmitter.emitter_id/0","type":"type"},{"doc":"","ref":"WebhooksEmitter.html#t:event_name/0","title":"WebhooksEmitter.event_name/0","type":"type"},{"doc":"","ref":"WebhooksEmitter.html#t:event_names/0","title":"WebhooksEmitter.event_names/0","type":"type"},{"doc":"","ref":"WebhooksEmitter.html#t:url/0","title":"WebhooksEmitter.url/0","type":"type"},{"doc":"Webhook emitter configuration.","ref":"WebhooksEmitter.Config.html","title":"WebhooksEmitter.Config","type":"module"},{"doc":"Set additional HTTP header to be sent along with the http request. Can be called multiple times. ## Examples iex&gt; &quot;https://host.tld/hooks&quot; ...&gt; |&gt; WebhooksEmitter.Config.new() ...&gt; |&gt; WebhooksEmitter.Config.additional_header({&quot;authorization&quot;, &quot;bearer 4242&quot;}) %WebhooksEmitter.Config{url: &quot;https://host.tld/hooks&quot;, additional_headers: [{&quot;authorization&quot;, &quot;bearer 4242&quot;}]} iex&gt; &quot;https://host.tld/hooks&quot; ...&gt; |&gt; WebhooksEmitter.Config.new() ...&gt; |&gt; WebhooksEmitter.Config.additional_header({&quot;authorization&quot;, &quot;bearer 4242&quot;}) ...&gt; |&gt; WebhooksEmitter.Config.additional_header({&quot;Access-Control-Allow-Origin&quot;, &quot;*&quot;}) %WebhooksEmitter.Config{url: &quot;https://host.tld/hooks&quot;, additional_headers: [{&quot;Access-Control-Allow-Origin&quot;, &quot;*&quot;}, {&quot;authorization&quot;, &quot;bearer 4242&quot;}]}","ref":"WebhooksEmitter.Config.html#additional_header/2","title":"WebhooksEmitter.Config.additional_header/2","type":"function"},{"doc":"Allow SSL insecure requests. Examples iex&gt; WebhooksEmitter.Config.new(&quot;https://host.tld/hooks&quot;) ...&gt; |&gt; WebhooksEmitter.Config.allow_insecure() %WebhooksEmitter.Config{url: &quot;https://host.tld/hooks&quot;, insecure: true}","ref":"WebhooksEmitter.Config.html#allow_insecure/1","title":"WebhooksEmitter.Config.allow_insecure/1","type":"function"},{"doc":"Disallow SSL insecure requests (the default). Examples iex&gt; WebhooksEmitter.Config.new(&quot;https://host.tld/hooks&quot;) ...&gt; |&gt; WebhooksEmitter.Config.disallow_insecure() %WebhooksEmitter.Config{url: &quot;https://host.tld/hooks&quot;, insecure: false}","ref":"WebhooksEmitter.Config.html#disallow_insecure/1","title":"WebhooksEmitter.Config.disallow_insecure/1","type":"function"},{"doc":"Allows to change the private header identifier. By default is Webhooks, so all private headers set by this library will have X-Webhooks prefix. ## Examples iex&gt; &quot;https://host.tld/hooks&quot; ...&gt; |&gt; WebhooksEmitter.Config.new() ...&gt; |&gt; WebhooksEmitter.Config.header_identifier(&quot;Yourapp&quot;) %WebhooksEmitter.Config{url: &quot;https://host.tld/hooks&quot;, header_identifier: &quot;Yourapp&quot;}","ref":"WebhooksEmitter.Config.html#header_identifier/2","title":"WebhooksEmitter.Config.header_identifier/2","type":"function"},{"doc":"Set the number of max retries for each delivery. Defaults to 3. ## Examples iex&gt; &quot;https://host.tld/hooks&quot; ...&gt; |&gt; WebhooksEmitter.Config.new() ...&gt; |&gt; WebhooksEmitter.Config.max_retries(43) %WebhooksEmitter.Config{url: &quot;https://host.tld/hooks&quot;, max_retries: 43}","ref":"WebhooksEmitter.Config.html#max_retries/2","title":"WebhooksEmitter.Config.max_retries/2","type":"function"},{"doc":"Returns a new emitter config with the destination url set. Examples iex&gt; WebhooksEmitter.Config.new(&quot;https://host.tld/hooks&quot;) %WebhooksEmitter.Config{url: &quot;https://host.tld/hooks&quot;}","ref":"WebhooksEmitter.Config.html#new/1","title":"WebhooksEmitter.Config.new/1","type":"function"},{"doc":"Set the HTTP request timeout, in milliseconds. By default is 5 seconds (5000 msec). ## Examples iex&gt; &quot;https://host.tld/hooks&quot; ...&gt; |&gt; WebhooksEmitter.Config.new() ...&gt; |&gt; WebhooksEmitter.Config.request_timeout(2000) %WebhooksEmitter.Config{url: &quot;https://host.tld/hooks&quot;, request_timeout: 2000}","ref":"WebhooksEmitter.Config.html#request_timeout/2","title":"WebhooksEmitter.Config.request_timeout/2","type":"function"},{"doc":"Add a secret, which is used to compute the hmac hex digest of the body. ## Examples iex&gt; &quot;https://host.tld/hooks&quot; ...&gt; |&gt; WebhooksEmitter.Config.new() ...&gt; |&gt; WebhooksEmitter.Config.secret(&quot;supersecret&quot;) %WebhooksEmitter.Config{url: &quot;https://host.tld/hooks&quot;, secret: &quot;supersecret&quot;}","ref":"WebhooksEmitter.Config.html#secret/2","title":"WebhooksEmitter.Config.secret/2","type":"function"},{"doc":"","ref":"WebhooksEmitter.Config.html#t:header/0","title":"WebhooksEmitter.Config.header/0","type":"type"},{"doc":"","ref":"WebhooksEmitter.Config.html#t:header_content/0","title":"WebhooksEmitter.Config.header_content/0","type":"type"},{"doc":"","ref":"WebhooksEmitter.Config.html#t:header_name/0","title":"WebhooksEmitter.Config.header_name/0","type":"type"},{"doc":"","ref":"WebhooksEmitter.Config.html#t:headers/0","title":"WebhooksEmitter.Config.headers/0","type":"type"},{"doc":"","ref":"WebhooksEmitter.Config.html#t:t/0","title":"WebhooksEmitter.Config.t/0","type":"type"},{"doc":"Helper module to recursively encode a term for safe json encoding. Basically converts to string terms that cannot be directly encoded as json, like lists, tuples, refs and so on.","ref":"WebhooksEmitter.Emitter.JsonSafeEncoder.html","title":"WebhooksEmitter.Emitter.JsonSafeEncoder","type":"module"},{"doc":"","ref":"WebhooksEmitter.Emitter.JsonSafeEncoder.html#encode/1","title":"WebhooksEmitter.Emitter.JsonSafeEncoder.encode/1","type":"function"},{"doc":"WebhooksEmitter Emits your events as outgoing http webhooks.","ref":"readme.html","title":"WebhooksEmitter","type":"extras"},{"doc":"The package can be installed by adding webhooks_emitter to your list of dependencies in mix.exs: def deps do [ {:webhooks_emitter, &quot;~&gt; 0.1.0&quot;} ] end","ref":"readme.html#installation","title":"WebhooksEmitter - Installation","type":"extras"},{"doc":"To start, a new configuration must be built using WebhooksEmitter.Config.new/1: iex&gt; config = WebhooksEmitter.Config.new(&quot;https://your.end.point&quot;) Then attach a new handler for the above config, using WebhooksEmitter.attach/3 to some event: iex&gt; :ok = WebhooksEmitter.attach(:my_emitter, :some_event, config) if the emitter id is already used, an error is returned: iex&gt; {:error, :already_exists} = WebhooksEmitter.attach(:already_used_id, :some_event, config) Is possible to attach the same config to a list of events, using WebhooksEmitter.attach_many/3. When your event is ready for dispatch, just call WebhooksEmitter.emit/3, with the payload and an optional request id, that will be added to the http request headers: iex&gt; {ok, request_id} = WebhooksEmitter.emit(:some_event, %{data: &quot;foobar&quot;}, &quot;an_optional_request_id&quot;) if the above request id is not passed, a new one will be automatically generated. To detach an emitter, just call WebhooksEmitter.detach/1 with your attached emitter id: iex&gt; :ok = WebhooksEmitter.detach(:my_emitter) Anatomy of an HTTP request performed by the emitter: POST /hooks/ah7Ahtet6abohbai HTTP/1.1 Host: localhost:1234 X-Webhooks-Event: averyimportantevent X-Webhooks-Delivery: fbc7fbe7-2e9b-4911-a50f-e0452672192c X-Webhooks-Signature: sha256:2vu2rb2moi6dihmlm6tvd3nbdnahjncmus9p8pl76h3v4ub054h0 User-Agent: WebHooks-Emitter/0.1.0 Content-Type: application/json Content-Length: 6615 { &quot;message&quot;: &quot;thank you for all the fish&quot;, ... }","ref":"readme.html#usage","title":"WebhooksEmitter - Usage","type":"extras"},{"doc":"Copyright 2020 Matteo Brancaleoni and VoiSmart S.R.L. Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"readme.html#license","title":"WebhooksEmitter - License","type":"extras"}]